==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/sd-Deva-IN.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sd-Deva-IN",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} \N{U+0924}\N{U+0947} {0}",
  datetime_format_long => "{1} \N{U+0924}\N{U+0947} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}\N{U+0917}",
    "\N{U+092c}\N{U+0941}\N{U+0952}\N{U+0927}",
    "\N{U+0935}\N{U+093f}\N{U+0938}",
    "\N{U+091c}\N{U+0941}\N{U+092e}",
    "\N{U+091b}\N{U+0902}\N{U+091b}",
    "\N{U+0906}\N{U+0930}\N{U+094d}\N{U+0924}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0952}",
    "\N{U+0935}\N{U+093f}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+091b}\N{U+0902}",
    "\N{U+0906}",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+0942}\N{U+092e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+0941}",
    "\N{U+092c}\N{U+0941}\N{U+0952}\N{U+0927}\N{U+0930}",
    "\N{U+0935}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+092a}\N{U+0924}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094b}",
    "\N{U+091b}\N{U+0902}\N{U+091b}\N{U+0930}",
    "\N{U+0906}\N{U+0930}\N{U+094d}\N{U+0924}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0927}",
    "\N{U+0935}\N{U+093f}\N{U+0938}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+091b}\N{U+0902}\N{U+091b}",
    "\N{U+0906}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0952}",
    "\N{U+0935}\N{U+093f}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+091b}\N{U+0902}",
    "\N{U+0906}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0952}\N{U+0927}",
    "\N{U+0935}\N{U+093f}\N{U+0938}",
    "\N{U+091c}\N{U+0941}\N{U+092e}",
    "\N{U+091b}\N{U+0902}\N{U+091b}",
    "\N{U+0906}\N{U+0930}\N{U+094d}\N{U+0924}",
  ],
  era_abbreviated => [
    "\N{U+092c}\N{U+0940}\N{U+0938}\N{U+0940}",
    "\N{U+090f}\N{U+0921}\N{U+0940}",
  ],
  era_narrow => [
    "\N{U+092c}\N{U+0940}\N{U+0938}\N{U+0940}",
    "\N{U+090f}\N{U+0921}\N{U+0940}",
  ],
  era_wide => [
    "\N{U+092c}\N{U+0940}\N{U+0938}\N{U+0940}",
    "\N{U+090f}\N{U+0921}\N{U+0940}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-d/%-m/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Sindhi",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+0928}",
    "\N{U+092b}\N{U+0930}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}",
    "\N{U+0928}\N{U+0935}\N{U+0902}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}",
  ],
  month_format_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}",
    "\N{U+0911}",
    "\N{U+0928}",
    "\N{U+0921}\N{U+093f}",
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}\N{U+0941}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+091f}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+0928}",
    "\N{U+092b}\N{U+0930}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}",
    "\N{U+0928}\N{U+0935}\N{U+0902}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}",
  ],
  month_stand_alone_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}",
    "\N{U+0911}",
    "\N{U+0928}",
    "\N{U+0921}\N{U+093f}",
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}\N{U+0941}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+091f}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  name => "Sindhi India Devanagari",
  native_language => "\N{U+0938}\N{U+093f}\N{U+0928}\N{U+094d}\N{U+0927}\N{U+0940}",
  native_name => "\N{U+0938}\N{U+093f}\N{U+0928}\N{U+094d}\N{U+0927}\N{U+0940} \N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924} \N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+093f}\N{U+0930}\N{U+0940}",
  native_script => "\N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+093f}\N{U+0930}\N{U+0940}",
  native_territory => "\N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0930}\N{U+0940} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0930}\N{U+0940} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0930}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0930}\N{U+0940} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  script => "Devanagari",
  territory => "India",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/sd-Deva-IN.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sd-Deva-IN",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}\N{U+0917}",
    "\N{U+092c}\N{U+0941}\N{U+0952}\N{U+0927}",
    "\N{U+0935}\N{U+093f}\N{U+0938}",
    "\N{U+091c}\N{U+0941}\N{U+092e}",
    "\N{U+091b}\N{U+0902}\N{U+091b}",
    "\N{U+0906}\N{U+0930}\N{U+094d}\N{U+0924}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0952}",
    "\N{U+0935}\N{U+093f}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+091b}\N{U+0902}",
    "\N{U+0906}",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+0942}\N{U+092e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+0941}",
    "\N{U+092c}\N{U+0941}\N{U+0952}\N{U+0927}\N{U+0930}",
    "\N{U+0935}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+092a}\N{U+0924}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094b}",
    "\N{U+091b}\N{U+0902}\N{U+091b}\N{U+0930}",
    "\N{U+0906}\N{U+0930}\N{U+094d}\N{U+0924}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0927}",
    "\N{U+0935}\N{U+093f}\N{U+0938}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+091b}\N{U+0902}\N{U+091b}",
    "\N{U+0906}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0952}",
    "\N{U+0935}\N{U+093f}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+091b}\N{U+0902}",
    "\N{U+0906}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+0942}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}\N{U+0952}\N{U+0927}",
    "\N{U+0935}\N{U+093f}\N{U+0938}",
    "\N{U+091c}\N{U+0941}\N{U+092e}",
    "\N{U+091b}\N{U+0902}\N{U+091b}",
    "\N{U+0906}\N{U+0930}\N{U+094d}\N{U+0924}",
  ],
  era_abbreviated => [
    "\N{U+092c}\N{U+0940}\N{U+0938}\N{U+0940}",
    "\N{U+090f}\N{U+0921}\N{U+0940}",
  ],
  era_narrow => [
    "\N{U+092c}\N{U+0940}\N{U+0938}\N{U+0940}",
    "\N{U+090f}\N{U+0921}\N{U+0940}",
  ],
  era_wide => [
    "\N{U+092c}\N{U+0940}\N{U+0938}\N{U+0940}",
    "\N{U+090f}\N{U+0921}\N{U+0940}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-d/%-m/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Sindhi",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+0928}",
    "\N{U+092b}\N{U+0930}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}",
    "\N{U+0928}\N{U+0935}\N{U+0902}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}",
  ],
  month_format_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}",
    "\N{U+0911}",
    "\N{U+0928}",
    "\N{U+0921}\N{U+093f}",
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}\N{U+0941}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+091f}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0913}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+0928}",
    "\N{U+092b}\N{U+0930}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}",
    "\N{U+0928}\N{U+0935}\N{U+0902}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}",
  ],
  month_stand_alone_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}\N{U+0917}",
    "\N{U+0938}",
    "\N{U+0911}",
    "\N{U+0928}",
    "\N{U+0921}\N{U+093f}",
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}\N{U+0941}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+091f}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  name => "Sindhi India Devanagari",
  native_language => "\N{U+0938}\N{U+093f}\N{U+0928}\N{U+094d}\N{U+0927}\N{U+0940}",
  native_name => "\N{U+0938}\N{U+093f}\N{U+0928}\N{U+094d}\N{U+0927}\N{U+0940} \N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924} \N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+093f}\N{U+0930}\N{U+0940}",
  native_script => "\N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+093f}\N{U+0930}\N{U+0940}",
  native_territory => "\N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0930}\N{U+0940} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0930}\N{U+0940} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0930}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0930}\N{U+0940} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+092c}\N{U+0940}\N{U+0902}\N{U+0952} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091f}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094b}\N{U+0925}\N{U+0940}\N{U+0902} \N{U+091f}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  script => "Devanagari",
  territory => "India",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => "44.1",
}
